@@ -2,6 +2,7 @@
 
 import json
 
+from collections import defaultdict
 from d3rlpy.gpu import get_gpu_count
 from flask import Blueprint, jsonify
 from ..models.experiment import Experiment, ExperimentSchema
@@ -10,6 +11,19 @@ from .project import _process_metrics
 system_route = Blueprint('system', __name__)
 
 
+def _get_device_id_and_data(experiment):
+    # identify device
+    config = json.loads(experiment.config)
+    device_id = config['use_gpu'] if 'use_gpu' in config else None
+
+    # make response data
+    data = ExperimentSchema().dump(experiment)
+    # update status
+    _process_metrics(experiment, data)
+
+    return device_id, data
+
+
 @system_route.route('/status', methods=['GET'])
 def get_system_status():
     n_gpus = get_gpu_count()
@@ -17,21 +31,11 @@ def get_system_status():
     # get all active experiments
     experiments = Experiment.create_query().filter(Experiment.is_active).all()
 
-    gpu_jobs = {}
+    gpu_jobs = defaultdict(list)
     cpu_jobs = []
     for experiment in experiments:
-        # identify device
-        config = json.loads(experiment.config)
-        device_id = config['use_gpu'] if 'use_gpu' in config else None
-
-        # make response data
-        data = ExperimentSchema().dump(experiment)
-        # update status
-        _process_metrics(experiment, data)
-
+        device_id, data = _get_device_id_and_data(experiment)
         if type(device_id) == int:
-            if device_id not in gpu_jobs:
-                gpu_jobs[device_id] = []
             gpu_jobs[device_id].append(data)
         else:
             cpu_jobs.append(data)
